==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_entities/inventorytransaction_001/InventoryTransaction.java <==

package net.datastream.schemas.mp_entities.inventorytransaction_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMBIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOCKCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ABCCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOCKDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDECHILDSTORES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDECONSIGNMENTITEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDEOUTOFSERVICEITEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "storeid",
    "transactionstatus",
    "partid",
    "partclassid",
    "frombin",
    "tobin",
    "stockclassid",
    "abccode",
    "stockdate",
    "includechildstores",
    "includeconsignmentitem",
    "includeoutofserviceitem",
    "assignedto",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "InventoryTransaction")
public class InventoryTransaction {

    @XmlElement(name = "TRANSACTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "TRANSACTIONSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type transactionstatus;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "PARTCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type partclassid;
    @XmlElement(name = "FROMBIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected BINID_Type frombin;
    @XmlElement(name = "TOBIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected BINID_Type tobin;
    @XmlElement(name = "STOCKCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type stockclassid;
    @XmlElement(name = "ABCCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String abccode;
    @XmlElement(name = "STOCKDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME stockdate;
    @XmlElement(name = "INCLUDECHILDSTORES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String includechildstores;
    @XmlElement(name = "INCLUDECONSIGNMENTITEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String includeconsignmentitem;
    @XmlElement(name = "INCLUDEOUTOFSERVICEITEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String includeoutofserviceitem;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété transactionid.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Définit la valeur de la propriété transactionid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété transactionstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getTRANSACTIONSTATUS() {
        return transactionstatus;
    }

    /**
     * Définit la valeur de la propriété transactionstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setTRANSACTIONSTATUS(STATUS_Type value) {
        this.transactionstatus = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété partclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getPARTCLASSID() {
        return partclassid;
    }

    /**
     * Définit la valeur de la propriété partclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setPARTCLASSID(CLASSID_Type value) {
        this.partclassid = value;
    }

    /**
     * Obtient la valeur de la propriété frombin.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getFROMBIN() {
        return frombin;
    }

    /**
     * Définit la valeur de la propriété frombin.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setFROMBIN(BINID_Type value) {
        this.frombin = value;
    }

    /**
     * Obtient la valeur de la propriété tobin.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getTOBIN() {
        return tobin;
    }

    /**
     * Définit la valeur de la propriété tobin.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setTOBIN(BINID_Type value) {
        this.tobin = value;
    }

    /**
     * Obtient la valeur de la propriété stockclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getSTOCKCLASSID() {
        return stockclassid;
    }

    /**
     * Définit la valeur de la propriété stockclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setSTOCKCLASSID(CLASSID_Type value) {
        this.stockclassid = value;
    }

    /**
     * Obtient la valeur de la propriété abccode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getABCCODE() {
        return abccode;
    }

    /**
     * Définit la valeur de la propriété abccode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setABCCODE(String value) {
        this.abccode = value;
    }

    /**
     * Obtient la valeur de la propriété stockdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTOCKDATE() {
        return stockdate;
    }

    /**
     * Définit la valeur de la propriété stockdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTOCKDATE(DATETIME value) {
        this.stockdate = value;
    }

    /**
     * Obtient la valeur de la propriété includechildstores.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDECHILDSTORES() {
        return includechildstores;
    }

    /**
     * Définit la valeur de la propriété includechildstores.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDECHILDSTORES(String value) {
        this.includechildstores = value;
    }

    /**
     * Obtient la valeur de la propriété includeconsignmentitem.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDECONSIGNMENTITEM() {
        return includeconsignmentitem;
    }

    /**
     * Définit la valeur de la propriété includeconsignmentitem.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDECONSIGNMENTITEM(String value) {
        this.includeconsignmentitem = value;
    }

    /**
     * Obtient la valeur de la propriété includeoutofserviceitem.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDEOUTOFSERVICEITEM() {
        return includeoutofserviceitem;
    }

    /**
     * Définit la valeur de la propriété includeoutofserviceitem.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDEOUTOFSERVICEITEM(String value) {
        this.includeoutofserviceitem = value;
    }

    /**
     * Obtient la valeur de la propriété assignedto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Définit la valeur de la propriété assignedto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Obtient la valeur de la propriété standardUserDefinedFields.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Définit la valeur de la propriété standardUserDefinedFields.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/inventorytransaction_001/InventoryTransaction.java <==

package net.datastream.schemas.mp_entities.inventorytransaction_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMBIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOCKCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ABCCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOCKDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDECHILDSTORES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDECONSIGNMENTITEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INCLUDEOUTOFSERVICEITEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "storeid",
    "transactionstatus",
    "partid",
    "partclassid",
    "frombin",
    "tobin",
    "stockclassid",
    "abccode",
    "stockdate",
    "includechildstores",
    "includeconsignmentitem",
    "includeoutofserviceitem",
    "assignedto",
    "createddate",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "InventoryTransaction")
public class InventoryTransaction {

    @XmlElement(name = "TRANSACTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "TRANSACTIONSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type transactionstatus;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "PARTCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type partclassid;
    @XmlElement(name = "FROMBIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected BINID_Type frombin;
    @XmlElement(name = "TOBIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected BINID_Type tobin;
    @XmlElement(name = "STOCKCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type stockclassid;
    @XmlElement(name = "ABCCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String abccode;
    @XmlElement(name = "STOCKDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME stockdate;
    @XmlElement(name = "INCLUDECHILDSTORES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String includechildstores;
    @XmlElement(name = "INCLUDECONSIGNMENTITEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String includeconsignmentitem;
    @XmlElement(name = "INCLUDEOUTOFSERVICEITEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String includeoutofserviceitem;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the transactionid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Sets the value of the transactionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the transactionstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getTRANSACTIONSTATUS() {
        return transactionstatus;
    }

    /**
     * Sets the value of the transactionstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setTRANSACTIONSTATUS(STATUS_Type value) {
        this.transactionstatus = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the partclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getPARTCLASSID() {
        return partclassid;
    }

    /**
     * Sets the value of the partclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setPARTCLASSID(CLASSID_Type value) {
        this.partclassid = value;
    }

    /**
     * Gets the value of the frombin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getFROMBIN() {
        return frombin;
    }

    /**
     * Sets the value of the frombin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setFROMBIN(BINID_Type value) {
        this.frombin = value;
    }

    /**
     * Gets the value of the tobin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getTOBIN() {
        return tobin;
    }

    /**
     * Sets the value of the tobin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setTOBIN(BINID_Type value) {
        this.tobin = value;
    }

    /**
     * Gets the value of the stockclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getSTOCKCLASSID() {
        return stockclassid;
    }

    /**
     * Sets the value of the stockclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setSTOCKCLASSID(CLASSID_Type value) {
        this.stockclassid = value;
    }

    /**
     * Gets the value of the abccode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getABCCODE() {
        return abccode;
    }

    /**
     * Sets the value of the abccode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setABCCODE(String value) {
        this.abccode = value;
    }

    /**
     * Gets the value of the stockdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTOCKDATE() {
        return stockdate;
    }

    /**
     * Sets the value of the stockdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTOCKDATE(DATETIME value) {
        this.stockdate = value;
    }

    /**
     * Gets the value of the includechildstores property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDECHILDSTORES() {
        return includechildstores;
    }

    /**
     * Sets the value of the includechildstores property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDECHILDSTORES(String value) {
        this.includechildstores = value;
    }

    /**
     * Gets the value of the includeconsignmentitem property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDECONSIGNMENTITEM() {
        return includeconsignmentitem;
    }

    /**
     * Sets the value of the includeconsignmentitem property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDECONSIGNMENTITEM(String value) {
        this.includeconsignmentitem = value;
    }

    /**
     * Gets the value of the includeoutofserviceitem property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINCLUDEOUTOFSERVICEITEM() {
        return includeoutofserviceitem;
    }

    /**
     * Sets the value of the includeoutofserviceitem property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINCLUDEOUTOFSERVICEITEM(String value) {
        this.includeoutofserviceitem = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
